@@ -6,6 +6,7 @@
 # SPDX-License-Identifier: MIT
 """cli module for BumpVer."""
 import io
+import re
 import sys
 import typing as typ
 import logging
@@ -36,7 +37,7 @@ except ImportError:
     pass  # no need to fail because of missing dev dependency
 
 
-click.disable_unicode_literals_warning = True
+click.disable_unicode_literals_warning = True  # type: ignore[attr-defined]
 
 logger = logging.getLogger("bumpver.cli")
 
@@ -44,6 +45,10 @@ logger = logging.getLogger("bumpver.cli")
 _VERBOSE = 0
 
 
+# pylint:disable=too-many-arguments; such is the cli
+# pylint:disable=too-many-locals; such is the cli
+
+
 def _configure_logging(verbose: int = 0) -> None:
     # pylint:disable=global-statement; global flag is global.
     global _VERBOSE
@@ -196,12 +201,12 @@ env_option = click.option(
 
 def version_options(function: typ.Callable) -> typ.Callable:
     decorators = [
-        click.option("--major", is_flag=True, default=False, help="Increment major component."),
+        click.option("--major", is_flag=True, default=False, help="Increment MAJOR component."),
         click.option(
-            "-m", "--minor", is_flag=True, default=False, help="Increment minor component."
+            "-m", "--minor", is_flag=True, default=False, help="Increment MINOR component."
         ),
         click.option(
-            "-p", "--patch", is_flag=True, default=False, help="Increment patch component."
+            "-p", "--patch", is_flag=True, default=False, help="Increment PATCH component."
         ),
         click.option(
             "-t",
@@ -242,7 +247,7 @@ def version_options(function: typ.Callable) -> typ.Callable:
 
 
 @click.group()
-@click.version_option(version="2021.1112")
+@click.version_option(version="2021.1113")
 @click.help_option()
 @verbose_option
 def cli(verbose: int = 0) -> None:
@@ -687,19 +692,27 @@ def _update_cfg_from_vcs(cfg: config.Config, fetch: bool) -> config.Config:
     ),
 )
 @version_options
+@click.option(
+    "-c",
+    "--commit-message",
+    default=None,
+    metavar="<TMPL>",
+    help="Set commit message template.",
+)
 def update(
-    dry        : bool = False,
-    allow_dirty: bool = False,
-    fetch      : bool = True,
-    verbose    : int = 0,
-    major      : bool = False,
-    minor      : bool = False,
-    patch      : bool = False,
-    tag        : typ.Optional[str] = None,
-    tag_num    : bool = False,
-    pin_date   : bool = False,
-    date       : typ.Optional[str] = None,
-    set_version: typ.Optional[str] = None,
+    dry           : bool = False,
+    allow_dirty   : bool = False,
+    fetch         : bool = True,
+    verbose       : int = 0,
+    major         : bool = False,
+    minor         : bool = False,
+    patch         : bool = False,
+    tag           : typ.Optional[str] = None,
+    tag_num       : bool = False,
+    pin_date      : bool = False,
+    date          : typ.Optional[str] = None,
+    set_version   : typ.Optional[str] = None,
+    commit_message: typ.Optional[str] = None,
 ) -> None:
     """Update project files with the incremented version string."""
     verbose = max(_VERBOSE, verbose)
@@ -747,18 +760,25 @@ def update(
     if dry or verbose >= 2:
         _print_diff(cfg, new_version)
 
-    if dry:
-        return
+    if commit_message is None:
+        commit_msg_template = cfg.commit_message
+    else:
+        commit_msg_template, _ = re.subn(r"\b(OLD|NEW)\b", r"{\1_VERSION}", commit_message)
 
     commit_message_kwargs = {
         'new_version'       : new_version,
         'old_version'       : old_version,
+        'NEW_VERSION'       : new_version,
+        'OLD_VERSION'       : old_version,
         'new_version_pep440': version.to_pep440(new_version),
         'old_version_pep440': version.to_pep440(old_version),
     }
-    commit_message = cfg.commit_message.format(**commit_message_kwargs)
+    try_commit_message = commit_msg_template.format(**commit_message_kwargs)
 
-    _try_update(cfg, new_version, commit_message, allow_dirty)
+    if dry:
+        return
+
+    _try_update(cfg, new_version, try_commit_message, allow_dirty)
 
 
 if __name__ == '__main__':
